bonesrunhome

## The server that runs a whole lot of nothing

bonesrunhome is an IBM x3550 M4 - it used to sit on my desk in my bedroom, however it is now in my rack in the living room, meaning I no longer have a lovely 1U space heater.

I wound up with it as UCC (UWA's University Computer Club) was throwing out a bunch of them due to the unfortunate habit they had of kamikazing themselves. Thankfully there was one remaining that hadn't blown up and with a firmware update it should hopefully not blow up anytime soon :P

I have since somehow wound up with a bunch more of these - they were for sale when I went to pickup the BladeCenter, and I couldn't say no (I should have). They are not in use now, and I can't see myself using them anytime soon ever - but they have had their firmware updated so they shouldn't blow up anymore! If you live in Perth and want some (I don't know why you would, they cost me $25, but at this point I would probably give you one if you asked nicely lol)

Anyway, back to bonesrunhome, which currently has two Xeon E5-2697 v2's (24 total cores at 3.50GHz) and 384GB of RAM with EndeavourOS as it's operating system. It used to live in my bedroom on my desk - which, considering it is a 1U server, was as painful as it sounds. However, after buying a rack it has been moved into my living room (sorry housemates). It currently runs "most" of my stuff on virtual machines (all setup through libvirt), including my FreeIPA setup, and the webserver hosting this, and my git server. You are welcome to try seeing my git server, just run `ssh git.mahoosively.gay` in your terminal (I have no idea if this works with Windows terminal as I avoid Windows as much as I can). I don't think I have really bothered to use this much for my public/collaborative, although I will hopefullly be using it more soon (group projects would not have been fans of me not using Github lol). I have setup a 4 drive raid-10 setup with mdadm to store the repos, so hopefully it will be reliable enough to use. If you want a bit more info on what the git server is, I am using Soft Serve